@@ -7,20 +7,36 @@ import pandas as pd
 import re
 import subprocess
 
-from .tables import IndexTable, IndexColumn, is_boolean
+from .tables import (
+    IndexTable,
+    IndexColumn,
+    is_boolean,
+    assert_dataframe,
+    assert_columns_presence,
+)
 from .utils import get_audio_duration, path_is_parent
 
 
 class ChildProject:
-    """This class is a representation of a ChildRecords dataset.
+    """ChildProject instance
+    This class is a representation of a ChildProject dataset
 
+    Constructor parameters:
+
+    :param path: path to the root of the dataset.
+    :type path: str
+    :param enforce_dtypes: enforce dtypes on children/recordings dataframes, defaults to False
+    :type enforce_dtypes: bool, optional
+    :param ignore_discarded: ignore entries such that discard=1, defaults to False
+    :type ignore_discarded: bool, optional
+    
     Attributes:
-        :param path: path to the root of the dataset.
-        :type path: str
-        :param recordings: pandas dataframe representation of this dataset metadata/recordings.csv 
-        :type recordings: class:`pd.DataFrame`
-        :param children: pandas dataframe representation of this dataset metadata/children.csv 
-        :type children: class:`pd.DataFrame`
+    :param path: path to the root of the dataset.
+    :type path: str
+    :param recordings: pandas dataframe representation of this dataset metadata/recordings.csv 
+    :type recordings: class:`pd.DataFrame`
+    :param children: pandas dataframe representation of this dataset metadata/children.csv 
+    :type children: class:`pd.DataFrame`
     """
 
     REQUIRED_DIRECTORIES = ["recordings", "extra"]
@@ -116,6 +132,12 @@ class ChildProject:
             description="date of birth accuracy",
             choices=["day", "week", "month", "year", "other"],
         ),
+        IndexColumn(
+            name="discard",
+            description="set to 1 if item should be discarded in analyses",
+            choices=["0", "1"],
+            required=False,
+        ),
     ]
 
     RECORDINGS_COLUMNS = [
@@ -186,6 +208,11 @@ class ChildProject:
         IndexColumn(name="upl_filename", description="upl_filename"),
         IndexColumn(name="trs_filename", description="trs_filename"),
         IndexColumn(name="lena_id", description=""),
+        IndexColumn(
+            name="lena_recording_num",
+            description="value of the corresponding <Recording> num's attribute, for LENA recordings that have been split into contiguous parts",
+            dtype="int",
+        ),
         IndexColumn(
             name="might_feature_gaps",
             description="1 if the audio cannot be guaranteed to be a continuous block with no time jumps, 0 or NA or undefined otherwise.",
@@ -205,6 +232,30 @@ class ChildProject:
             name="notes",
             description="free-style notes about individual recordings (avoid tabs and newlines)",
         ),
+        IndexColumn(
+            name="discard",
+            description="set to 1 if item should be discarded in analyses",
+            choices=["0", "1"],
+            required=False,
+        ),
+    ]
+
+    DOCUMENTATION_COLUMNS = [
+        IndexColumn(
+            name="variable",
+            description="name of the variable",
+            unique=True,
+            required=True,
+        ),
+        IndexColumn(
+            name="description", description="a definition of this field", required=True
+        ),
+        IndexColumn(name="values", description="a summary of authorized values"),
+        IndexColumn(name="scope", description="which group of users has access to it"),
+        IndexColumn(
+            name="annotation_set",
+            description="for annotations: which set(s) contain this variable",
+        ),
     ]
 
     RAW_RECORDINGS = "recordings/raw"
@@ -212,14 +263,12 @@ class ChildProject:
 
     PROJECT_FOLDERS = ["recordings", "annotations", "metadata", "doc", "scripts"]
 
-    def __init__(self, path: str, enforce_dtypes: bool = False):
-        """Constructor
-
-        :param path: path to the root of the dataset.
-        :type path: str
-        """
+    def __init__(
+        self, path: str, enforce_dtypes: bool = False, ignore_discarded: bool = False
+    ):
         self.path = path
         self.enforce_dtypes = enforce_dtypes
+        self.ignore_discarded = ignore_discarded
 
         self.errors = []
         self.warnings = []
@@ -310,13 +359,13 @@ class ChildProject:
             "children",
             os.path.join(self.path, "metadata/children.csv"),
             self.CHILDREN_COLUMNS,
-            enforce_dtypes=self.enforce_dtypes
+            enforce_dtypes=self.enforce_dtypes,
         )
         self.rt = IndexTable(
             "recordings",
             os.path.join(self.path, "metadata/recordings.csv"),
             self.RECORDINGS_COLUMNS,
-            enforce_dtypes=self.enforce_dtypes
+            enforce_dtypes=self.enforce_dtypes,
         )
 
         self.children = self.ct.read()
@@ -334,6 +383,12 @@ class ChildProject:
             verbose,
         )
 
+        if self.ignore_discarded and "discard" in self.ct.df:
+            self.ct.df = self.ct.df[self.ct.df["discard"].astype(str) == "1"]
+
+        if self.ignore_discarded and "discard" in self.rt.df:
+            self.rt.df = self.rt.df[self.rt.df["discard"].astype(str) == "1"]
+
         self.children = self.ct.df
         self.recordings = self.rt.df
 
@@ -458,11 +513,15 @@ class ChildProject:
         """
 
         if profile:
+            converted_filename = self.get_converted_recording_filename(
+                profile, recording_filename
+            )
+
+            if converted_filename is None:
+                return None
+
             return os.path.join(
-                self.path,
-                self.CONVERTED_RECORDINGS,
-                profile,
-                self.get_converted_recording_filename(profile, recording_filename),
+                self.path, self.CONVERTED_RECORDINGS, profile, converted_filename,
             )
         else:
             return os.path.join(self.path, self.RAW_RECORDINGS, recording_filename)
@@ -535,6 +594,10 @@ class ChildProject:
         :rtype: pd.DataFrame
         """
         _recordings = self.recordings.copy()
+        _recordings = _recordings[
+            (~_recordings["recording_filename"].isnull())
+            & (_recordings["recording_filename"] != "NA")
+        ]
 
         if recordings is not None:
             # if the user provided paths,
@@ -571,3 +634,92 @@ class ChildProject:
         recordings["duration"] = (recordings["duration"] * 1000).astype(int)
 
         return recordings
+
+    def compute_ages(
+        self, recordings: pd.DataFrame = None, children: pd.DataFrame = None
+    ) -> pd.Series:
+        """Compute the age of the subject child for each recording (in months, as a float)
+        and return it as a pandas Series object.
+
+        Example:
+
+        >>> from ChildProject.projects import ChildProject
+        >>> project = ChildProject("examples/valid_raw_data")
+        >>> project.read()
+        >>> project.recordings["age"] = project.compute_ages()
+        >>> project.recordings[["child_id", "date_iso", "age"]]
+            child_id    date_iso       age
+        line                                
+        2            1  2020-04-20  3.613963
+        3            1  2020-04-21  3.646817
+
+        :param recordings: custom recordings DataFrame (see :ref:`format-metadata`), otherwise use all project recordings, defaults to None
+        :type recordings: pd.DataFrame, optional
+        :param children: custom children DataFrame (see :ref:`format-metadata`), otherwise use all project children data, defaults to None
+        :type children: pd.DataFrame, optional
+        """
+
+        def date_is_valid(date: str, fmt: str):
+            try:
+                datetime.datetime.strptime(date, fmt)
+            except:
+                return False
+            return True
+
+        if recordings is None:
+            recordings = self.recordings.copy()
+
+        if children is None:
+            children = self.children.copy()
+
+        assert_dataframe("recordings", recordings)
+        assert_dataframe("children", children)
+
+        assert_columns_presence("recordings", recordings, {"date_iso", "child_id"})
+        assert_columns_presence("children", children, {"child_dob", "child_id"})
+
+        index = recordings.index
+        recordings = recordings.merge(
+            children[["child_id", "child_dob"]],
+            how="left",
+            left_on="child_id",
+            right_on="child_id",
+        )
+        recordings.index = index
+
+        age = (
+            recordings[["date_iso", "child_dob"]]
+            .apply(
+                lambda r: (
+                    datetime.datetime.strptime(r["date_iso"], "%Y-%m-%d")
+                    - datetime.datetime.strptime(r["child_dob"], "%Y-%m-%d")
+                )
+                if (
+                    date_is_valid(r["child_dob"], "%Y-%m-%d")
+                    and date_is_valid(r["date_iso"], "%Y-%m-%d")
+                )
+                else None,
+                axis=1,
+            )
+            .apply(lambda dt: dt.days / (365.25 / 12) if dt else None)
+        )
+
+        return age
+
+    def read_documentation(self) -> pd.DataFrame:
+        docs = ["children", "recordings", "annotations"]
+
+        documentation = []
+
+        for doc in docs:
+            path = os.path.join(self.path, "docs", f"{doc}.csv")
+
+            if not os.path.exists(path):
+                continue
+
+            table = IndexTable(f"{doc}-documentation", path, self.DOCUMENTATION_COLUMNS)
+            table.read()
+            documentation.append(table.df.assign(table=doc))
+
+        documentation = pd.concat(documentation)
+        return documentation
